Contributing to MNE-Python
==========================

MNE-Python is maintained by a community of scientists and research labs, and
accepts contributions in the form of bug reports, fixes, feature additions, and
documentation improvements (even just typo corrections). The best way to start
contributing is by `opening an issue`_ on our GitHub page to discuss your ideas
for changes or enhancements, or to tell us about behavior that you think might
be a bug in MNE-Python. *For general troubleshooting of scripts that use
MNE-Python*, you should instead write to the `MNE mailing list`_ or chat with
developers on the `MNE gitter channel`_. Users and contributors to MNE-Python
are expected to follow our `code of conduct`_.

The `contributing guide`_ has details on the preferred contribution workflow
and how best to configure your system for a smooth experience contributing to
MNE-Python.


.. _`opening an issue`: https://github.com/mne-tools/mne-python/issues/new/choose
.. _`MNE mailing list`: http://mail.nmr.mgh.harvard.edu/mailman/listinfo/mne_analysis
.. _`MNE gitter channel`: https://gitter.im/mne-tools/mne-python

.. _`code of conduct`: https://github.com/mne-tools/.github/blob/master/CODE_OF_CONDUCT.md
.. _`contributing guide`: https://mne-tools.github.io/dev/install/contributing.html
